package HTFeed::Namespace::MIUA;

use strict;
use warnings;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'miua';

our $config = {

    handle_prefix => '2027/miua',

    description => 'University of Michigan, legacy DLXS content with Aleph system ID',

    packagetypes => [qw(ht dlxs)],
};


# example: 5285173.0001.001 (miua namespace),

sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;


    return $barcode =~ /^\d{3}[a-z\d-]{4}\.[a-z\d-]{4}\.[a-z\d-]{3}$/;
}

1;
__END__

=pod

This is the namespace configuration file for the University of Michigan DLPS material with Aleph IDs.

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('miua');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2011 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
