package HTFeed::Namespace::PST;
use strict;
use warnings;
use HTFeed::Namespace ;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'pst';

our $config = {

    # The GRIN ID
    grinid => 'PSU',
    packagetypes => [qw(ht google)],

    handle_prefix => '2027/pst',
    description => 'Penn State',

    tags => [qw(bib cic pd_only report)]
};


# Returns true if the given barcode is a valid UPCA.

sub upca_is_valid {
    my $self = shift;

    my $barcode = shift;
    my $char;
    my @chars = split(//, $barcode);
    my $odd = 0;
    my $even = 0;
    my $sum = 0;
    my $position = 0;
    my $mod;

    my $check = substr($barcode, (length($barcode)-1),1);   # get check digit
    my $drop = pop(@chars);                                 #remove check digit

    foreach $char(@chars) {
        $position = $position + 1;
        if ($position % 2) {   #if odd
            $odd = $odd + $char;
        } else {
            $even = $even + $char
        }
    }

    $odd = $odd * 3;
    $sum = $odd + $even;

    if ($sum % 10 == 0) {
        $mod = 0;
    }   else {
        $mod = 10 - ($sum % 10);
    }

    if ($check eq $mod) {
        return 1;
    }   else {
        return 0;
    }

}

sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;
    return ($self->luhn_is_valid('32239',$barcode)  # Dickinson and/or Hershey??
        or  $barcode =~ /^0000\d{8}/ && $self->upca_is_valid($barcode)); # General case
}

1;

__END__

=pod

This is the namespace configuration file for Pennsylvania State University.

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('pst');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2010 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
