package HTFeed::Namespace::UC1;
use strict;
use warnings;
use HTFeed::Namespace ;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'uc1';

our $config = {

    # The GRIN ID
    grinid => 'UCAL',
    packagetypes => [qw(ht google)],

    handle_prefix => '2027/uc1',
    description => 'University of California (Barcoded material)',
    tags => [qw(bib report)]
};

# Allow filenames prefixed with institution & object ID
our $packagetype_overrides = {
    google => {
	valid_file_pattern => qr/( 
		    checksum\.md5 |
		    ^[\w\$]+\.(xml) |
		    \d{8}.(html|jp2|tif|txt)
		    )/x,
    }

};

sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;
    return ($barcode =~ /^\$?b\d{1,9}$/ # UCB, NRLF - no checksum digit, optional leading $
	or  $self->luhn_is_valid('31822',$barcode)  # USCD
	or  $self->luhn_is_valid('31158',$barcode)  # UCLA
	or  $self->luhn_is_valid('32106',$barcode)  # UCSC
    # 11 characters beginning with L, allegedly 'MOD 10' - UCLA
    or  ($barcode =~ /^l(\d{10})/ and Algorithm::LUHN::is_valid($1))
	# or 10 char + 1, 2 or 3 leading A's & complicated checksum - SRLF
	# or 10 char beginning with C & complicated checksum - UCB alternate
    );
}

1;

__END__

=pod

This is the namespace configuration file for the University of California.

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('uc1');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2010 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
