package HTFeed::Namespace::UCM;
use strict;
use warnings;
use HTFeed::Namespace ;
use base qw(HTFeed::Namespace);

# The HathiTrust namespace
our $identifier = 'ucm';

our $config = {

    # The GRIN ID
    grinid => 'UCM',
    packagetypes => [qw(ht google ucm)],

    handle_prefix => '2027/ucm',
    description => 'Universidad Complutense de Madrid',
    tags => [qw(bib report)]
};



sub validate_barcode {
    my $self    = shift;
    my $barcode = shift;

    my @weights = (0,7,8,4,6,3,5,2,1);

    if($barcode && $barcode =~ /^(48|49|53)\d{7}[\dx]$/)  {
        my @barcode_pos = split('',$barcode);
        my $sum = 0;
        my $old_check = pop(@barcode_pos);
        for(my $i = 0; $i < 9; $i++) {
            $sum += $weights[$i] * $barcode_pos[$i];
        }
        my $new_check = 11 - ($sum % 11);
        if($new_check < 10) {
            # new check is OK
        } elsif ($new_check == 10) {
            $new_check = 'x' 
        } else { #new_check == 11
            $new_check = 0;
        }

        return 1 if($old_check eq $new_check);

    }

    # bad check digit or regex didn't match
    return;

}

1;

__END__

=pod

This is the namespace configuration file for the Universidad Complutense de Madrid.

=head1 SYNOPSIS

use HTFeed::Namespace;

my $namespace = new HTFeed::Namespace('ucm');

=head1 AUTHOR

Aaron Elkiss, University of Michigan, aelkiss@umich.edu

=head1 COPYRIGHT

Copyright (c) 2011 University of Michigan. All rights reserved.  This program
is free software; you can redistribute it and/or modify it under the same terms
as Perl itself.

=cut
