package HTFeed::PackageType::Google::Unpack;

use warnings;
use strict;
use IO::Handle;
use IO::File;
use IPC::Open3;

use base qw(HTFeed::Stage::Unpack);

use HTFeed::Config qw(get_config);

use Log::Log4perl qw(get_logger);

sub run{
    my $self = shift;
    # make staging directories
    $self->SUPER::run();
    my $volume = $self->{volume};
    
    my $download_dir = $volume->get_download_directory();
    
    my $objid = $volume->get_objid();

    my $file = $volume->get_download_location();
    # check that file exists
    if (-e $file){
        # unpack    
        $self->_unpack($file,$volume->get_staging_directory()) or return;
    }
    else{
        $self->set_error('MissingFile',file=>$file);
        return;
    }
    
    $self->_set_done();
    return $self->succeeded();
}

# _unpack($in_file,$outdir)
sub _unpack{
    my $self = shift;
    my $infile = shift;
    my $outdir = shift;
    my $volume = $self->{volume};

    my $pass_file = $volume->get_nspkg()->get_gpg();
    
    
    my $gpg_out = new IO::Handle;
    local $/; # turn on slurp mode for output from pipeline

    # Capture both stdout and stderr from GPG output without nasty shell redirections
    my $pid = open3(undef,$gpg_out,$gpg_out,"cat '$pass_file' | gpg -q --passphrase-fd 0 --batch --no-tty --decrypt '$infile' | tar -zx -C '$outdir'");

    waitpid($pid, 0);
    my $child_exit_status = $? >> 8;

    my $results = <$gpg_out>;
    if($results =~ /decryption failed/ or $child_exit_status) {
       $self->set_error('OperationFailed',operation=>'decrypt',detail=>"Pipeline exited with status $child_exit_status, output was '$results'");
       return;
    } else {
       get_logger()->debug("$infile decrypted successfully");
       $volume->record_premis_event('decryption');
       return 1;
    }
}

# do cleaning that is appropriate after failure
sub clean_failure{
    my $self = shift;
    $self->{volume}->clean_download();
    $self->{volume}->clean_zip();
    return $self->{volume}->clean_unpacked_object();
}

1;

__END__
